% Convert weather data
%
% This function reads in weather data from file and converts
% some things into correct format.
%
% Syntax:  convweat()
%
% Input parameter:
%    no input parameter
%
% Output parameter:
%    no output parameter
%
% See also: klidata4

% Author:   Hartmut Pohlheim
% History:  10.03.97    file created


function convweat()
 
% Get days per month
   DaysperMonth = [0 compgrhs('hours_per_month')]/24;

% Wind data
   % Month=[ 1     2     3     4     5     6     7     8     9    10    11    12
   UDat = [4.9   4.9   4.3   4.3   4.3   4.0   4.0   4.3   4.3   4.9   4.9   4.9; 
           4.9   4.9   4.3   4.3   4.3   4.0   4.0   4.3   4.3   4.9   4.9   4.9; 
           4.8   4.8   4.4   4.4   4.4   4.0   4.0   4.4   4.4   4.8   4.8   4.8; 
           4.8   4.8   4.3   4.3   4.3   4.0   4.0   4.3   4.3   4.8   4.8   4.8; 
           4.7   4.7   4.2   4.2   4.2   3.8   3.8   4.2   4.2   4.7   4.7   4.7; 
           4.7   4.7   4.1   4.1   4.1   3.6   3.6   4.1   4.1   4.7   4.7   4.7; 
           4.7   4.7   4.0   4.0   4.0   3.6   3.6   4.0   4.0   4.7   4.7   4.7; 
           4.7   4.7   4.1   4.1   4.1   3.9   3.9   4.1   4.1   4.7   4.7   4.7; 
           4.6   4.6   4.2   4.2   4.2   4.0   4.0   4.2   4.2   4.6   4.6   4.6; 
           4.7   4.7   4.5   4.5   4.5   4.2   4.2   4.5   4.5   4.7   4.7   4.7; 
           4.8   4.8   4.6   4.6   4.6   4.3   4.3   4.6   4.6   4.8   4.8   4.8; 
           4.8   4.8   4.6   4.6   4.6   4.4   4.4   4.6   4.6   4.8   4.8   4.8; 
           4.9   4.9   4.6   4.6   4.6   4.4   4.4   4.6   4.6   4.9   4.9   4.9; 
           4.9   4.9   4.6   4.6   4.6   4.4   4.4   4.6   4.6   4.9   4.9   4.9; 
           4.7   4.7   4.5   4.5   4.5   4.3   4.3   4.5   4.5   4.7   4.7   4.7; 
           4.5   4.5   4.4   4.4   4.4   4.3   4.3   4.4   4.4   4.5   4.5   4.5; 
           4.5   4.5   4.2   4.2   4.2   4.1   4.1   4.2   4.2   4.5   4.5   4.5; 
           4.7   4.7   4.1   4.1   4.1   4.0   4.0   4.1   4.1   4.7   4.7   4.7; 
           4.8   4.8   4.0   4.0   4.0   3.7   3.7   4.0   4.0   4.8   4.8   4.8; 
           4.9   4.9   4.0   4.0   4.0   3.8   3.8   4.0   4.0   4.9   4.9   4.9; 
           4.9   4.9   4.1   4.1   4.1   3.9   3.9   4.1   4.1   4.9   4.9   4.9; 
           4.9   4.9   4.2   4.2   4.2   4.0   4.0   4.2   4.2   4.9   4.9   4.9; 
           4.9   4.9   4.3   4.3   4.3   4.0   4.0   4.3   4.3   4.9   4.9   4.9; 
           4.9   4.9   4.3   4.3   4.3   4.0   4.0   4.3   4.3   4.9   4.9   4.9
          ]; 
        
% Load data from one file
   FileIGLOB = 'new_weat\gs011095.dat';
   [Header, IGLOBData] = hdrload(FileIGLOB);
   disp(sprintf('First weather data file: %s', FileIGLOB));
   % Extract something
   IGLOBperHour = IGLOBData(:, 4:27);
   IGLOBMonth = IGLOBData(:, 2); IGLOBDay = IGLOBData(:, 3);
   StartDayIGLOB = DaysperMonth(IGLOBMonth(1)) + IGLOBDay(1);
   EndDayIGLOB = size(IGLOBData,1);
        
% Load data from another file
   FileTEMP = 'new_weat\frra9502.fix';
   [Header, TEMPData] = hdrload(FileTEMP);
   disp(sprintf('Second weather data file: %s', FileTEMP));
   % Extract something
   TEMPMonth = TEMPData(:,2);
   TEMPDay = TEMPData(:,1);
   TEMPDayA = TEMPData(:,4);
   TEMPHour = TEMPData(:,5);
   TEMPFeuchte = TEMPData(:,6);
   TEMPBoden = TEMPData(:,9);
   TEMPLuft = TEMPData(:,12);
   StartDayTEMP = TEMPDayA(1);
   EndDayTEMP = TEMPDayA(length(TEMPDayA));
        
   StartDay = max(StartDayIGLOB, StartDayTEMP);
   EndDay = min(EndDayIGLOB, EndDayTEMP);
   
   % Write header
   FileWeather = 'weat95_2.wth';
   [fid, error_message] = fopen(FileWeather, 'wt');
   if fid == -1, error(sprintf('error during fopen: %s', error_message));
   else
      TitleString1 = [' Monat';'   Tag';'TagAll';'Stunde';'Zeit_s'];
      for iout = 1:size(TitleString1,1), fprintf(fid,'%9s', sprintf('%s',TitleString1(iout,:))); end
      TitleString2 = [' TEMB_C';' TEMG_C';' TEMA_C';'  FA_%rF';'  CA_ppm';'IGL_W/m';'   U_m/s'];
      for iout = 1:size(TitleString2,1), fprintf(fid,'%10s', sprintf('%s',TitleString2(iout,:))); end
      fprintf(fid, '\n');
   end
   
   DayofYear = StartDay;
   IGLOBLastGood = zeros(size(IGLOBperHour,2));
   for iday = 1:(EndDay-StartDay+1),
      for ihour = 1:24,
         if IGLOBperHour(DayofYear,ihour) == -999, IGLOB = IGLOBLastGood(ihour); else IGLOB = IGLOBperHour(DayofYear,ihour); end
         % Convert IGLOB from J/cm (Stundensumme) to W/m [*10000cm/m / (3600s/1h)] 
         IGLOB = IGLOB * 10 / 3.6;
         Time_s = ((DayofYear-1)*24 + (ihour)) * 3600;
         
         fprintf(fid, '%9d', [IGLOBMonth(DayofYear), IGLOBDay(DayofYear), DayofYear, ihour, Time_s]);
         TIx = (iday-1)*24+ihour;
         TEMG = 0; CA = 340;
         fprintf(fid, '%10.4g',[TEMPBoden(TIx), TEMG, TEMPLuft(TIx), TEMPFeuchte(TIx), CA, IGLOB, UDat(ihour, IGLOBMonth(DayofYear))]);
         fprintf(fid, '\n');
      end
      if all([IGLOBperHour(DayofYear,:) ~= -999]), IGLOBLastGood = IGLOBperHour(DayofYear,:);
      else
         % disp(sprintf('%d  %d  %d',Month(iday),Day(iday),iday));
      end
   
      DayofYear = DayofYear + 1;
   end
   
   fclose(fid);
   disp(sprintf('Weather data file created: %s', FileWeather));
   disp(sprintf('First day: %2d.%02d (%3d)', IGLOBDay(StartDay), IGLOBMonth(StartDay), StartDay));
   disp(sprintf('Last  day: %2d.%02d (%3d)', IGLOBDay(EndDay), IGLOBMonth(EndDay), EndDay));

   
% End of function
