% INITialzation function for GReenHouSe climate model 4
%
% This function initializes the greenhouse climate model.
%
% Syntax:  [Chrom, VLUB] = initgrh4(Nind, VLUB, Method, TSTART, TEND, DataKlimaPlant, XINIT, PRICES)
%
% Input parameters:
%    Nind      - Number of individuals
%    VLUB      - Matrix containing the boundaries of the variables
%    Method    - (optional) PlantModel
%    TSTART    - (optional) start time
%    TEND      - (optional) end time
%    DataKlimaPlant - (optional) matrix with data of Klima and Plant
%    XINIT     - (optional) initial values of state variables
%    PRICES    - (optional) prices of control and gemuese
%
% Output parameters:
%    Chrom     - Matrix containing the chromosomes of the current
%                population. Each row corresponds to one individual's
%                string representation.
%    VLUB      - (optional) Matrix containing the new boundaries
%                of the variables
%                
% See also: objgrhs4, initfun1

% Author:     Hartmut Pohlheim
% History:    01.04.97     file created


function [Chrom, VLUB] = initgrh4(Nind, VLUB, method, TSTART, TEND, DataKlimaPlant, XINIT, PRICES);

% Check input parameters 


% Compute the month from time
   MonthInt = compgrhs('convert_time2month', TSTART);
   MonthInt = MonthInt(1);
   
% Select actual, previous and next month's for using as possible start values
   IxInitMonth = rem([MonthInt,MonthInt-2, MonthInt-1, MonthInt+1, MonthInt+2] + 11, 12) + 1;

% Set initialization parameter
   % Month = [          1    2    3    4    5    6    7    8    9   10   11   12]
   InitHeating = [ 0, 110, 110, 110,  80,  80,  20,  20,  20,  80, 110, 110, 110;
                   1, 110, 110, 110,  80,  80,  20,  20,  20,  80, 110, 110, 110;
                   2, 110, 110, 110,  80,  80,  20,  20,  20,  80, 110, 110, 110;
                   3, 110, 110, 110,  80,  80,  20,  20,  20,  80, 110, 110, 110;
                   4, 110, 110, 110,  80,  80,  10,  10,  10,  80, 110, 110, 110;
                   5, 110, 110, 110,  80,  80,   0,   0,   0,  80, 110, 110, 110;
                   6, 110, 110, 110,  70,  70,   0,   0,   0,  70, 110, 110, 110;
                   7, 100, 100, 100,  40,  40,   0,   0,   0,  40, 100, 100, 100;
                   8,  90,  90,  90,  20,  20,   0,   0,   0,  20,  90,  90,  90;
                   9,  80,  80,  80,   0,   0,   0,   0,   0,   0,  80,  80,  80;
                  10,  60,  60,  60,   0,   0,   0,   0,   0,   0,  60,  60,  60;
                  11,  40,  40,  40,   0,   0,   0,   0,   0,   0,  40,  40,  40;
                  12,  20,  20,  20,   0,   0,   0,   0,   0,   0,  20,  20,  20;
                  13,  20,  20,  20,   0,   0,   0,   0,   0,   0,  20,  20,  20;
                  14,  20,  20,  20,   0,   0,   0,   0,   0,   0,  20,  20,  20;
                  15,  50,  50,  50,   0,   0,   0,   0,   0,   0,  50,  50,  50;
                  16,  80,  80,  80,  10,  10,   0,   0,   0,  10,  80,  80,  80;
                  17, 100, 100, 100,  20,  20,   0,   0,   0,  20, 100, 100, 100;
                  18, 100, 100, 100,  40,  40,   0,   0,   0,  40, 100, 100, 100;
                  19, 100, 100, 100,  50,  50,   0,   0,   0,  50, 100, 100, 100;
                  20, 110, 110, 110,  60,  60,   0,   0,   0,  60, 110, 110, 110;
                  21, 110, 110, 110,  60,  60,   0,   0,   0,  60, 110, 110, 110;
                  22, 110, 110, 110,  70,  70,  15,  15,  15,  70, 110, 110, 110;
                  23, 110, 110, 110,  70,  70,  20,  20,  20,  70, 110, 110, 110;
                  24, 110, 110, 110,  80,  80,  20,  20,  20,  80, 110, 110, 110;
                 ];

   % Month = [          1    2    3    4    5    6    7    8    9   10   11   12]
   InitVentilat= [ 0,   1,   1,   1,   1,   1,   1,   1,   1,   1,   1,   1,   1,
                   1,   1,   1,   1,   1,   1,   1,   1,   1,   1,   1,   1,   1,
                   2,   1,   1,   1,   1,   1,   1,   1,   1,   1,   1,   1,   1,
                   3,   1,   1,   1,   1,   1,   1,   1,   1,   1,   1,   1,   1,
                   4,   1,   1,   1,   1,   1,   1,   1,   1,   1,   1,   1,   1,
                   5,   1,   1,   1,   1,   1,   1,   1,   1,   1,   1,   1,   1,
                   6,   1,   1,   1,   1,   1,   1,   1,   1,   1,   1,   1,   1,
                   7,   1,   1,   1,   1,   1,   5,   5,   5,   1,   1,   1,   1,
                   8,   1,   1,   1,   1,   5,  30,  30,  20,   5,   1,   1,   1,
                   9,   1,   1,   1,   1,  10,  40,  40,  30,  10,   1,   1,   1,
                  10,   1,   1,   1,   5,  20,  50,  50,  40,  20,   1,   1,   1,
                  11,   1,   1,   1,  10,  30,  60,  60,  45,  30,   1,   1,   1,
                  12,   1,   1,   1,  15,  40,  80,  80,  50,  40,   1,   1,   1,
                  13,   1,   1,   1,  20,  50, 100, 100,  60,  50,   1,   1,   1,
                  14,   1,   1,   1,  25,  50, 100, 100,  60,  50,   1,   1,   1,
                  15,   1,   1,   1,  20,  50, 100, 100,  40,  50,   1,   1,   1,
                  16,   1,   1,   1,  10,  20,  30,  30,  20,  20,   1,   1,   1,
                  17,   1,   1,   1,   5,  10,  20,  20,  10,   5,   1,   1,   1,
                  18,   1,   1,   1,   1,   1,  10,  10,   1,   1,   1,   1,   1,
                  19,   1,   1,   1,   1,   1,   1,   1,   1,   1,   1,   1,   1,
                  20,   1,   1,   1,   1,   1,   1,   1,   1,   1,   1,   1,   1,
                  21,   1,   1,   1,   1,   1,   1,   1,   1,   1,   1,   1,   1,
                  22,   1,   1,   1,   1,   1,   1,   1,   1,   1,   1,   1,   1,
                  23,   1,   1,   1,   1,   1,   1,   1,   1,   1,   1,   1,   1,
                  24,   1,   1,   1,   1,   1,   1,   1,   1,   1,   1,   1,   1,
               ];
                  
                  
   % Month = [          1    2    3    4    5    6    7    8    9   10   11   12]
   InitCO2Inj  = [ 0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0;
                   1,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0;
                   2,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0;
                   3,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0;
                   4,   0,   0,   0,   0,   0,  10,  10,   0,   0,   0,   0,   0;
                   5,   0,   0,   0,   0,   0,   5,   5,   0,   0,   0,   0,   0;
                   6,   0,   0,   0,   0,   0,   5,   5,   0,   0,   0,   0,   0;
                   7,   0,   0,   0,   0,   0,  10,  10,   0,   0,   0,   0,   0;
                   8,   0,   0,   0,   2,   2,   0,   0,   2,   2,   0,   0,   0;
                   9,   0,   0,   0,   4,   4,   0,   0,   4,   4,   0,   0,   0;
                  10,   0,   0,   0,   5,   5,   0,   0,   5,   5,   0,   0,   0;
                  11,  .5,  .5,  .5,   5,   5,   0,   0,   5,   5,  .5,  .5,  .5;
                  12,   1,   1,   1,   7,   7,   0,   0,   7,   7,   1,   1,   1;
                  13,   1,   1,   1,   5,   5,   0,   0,   5,   5,   1,   1,   1;
                  14,  .5,  .5,  .5,   3,   3,   0,   0,   3,   3,  .5,  .5,  .5;
                  15,  .5,  .5,  .5,   2,   2,   0,   0,   2,   2,  .5,  .5,  .5;
                  16,   0,   0,   0,   1,   1,   0,   0,   1,   1,   0,   0,   0;
                  17,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0;
                  18,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0;
                  19,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0;
                  20,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0;
                  21,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0;
                  22,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0;
                  23,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0;
                  24,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0;
               ];
 
% Compute population parameters
    Nvar = size(VLUB, 2);
  
    NCONTR = 3;
    NumContrValues = Nvar / NCONTR;
    ContrTime = rem(linspace(TSTART, TEND, NumContrValues)./3600, 24)';

% Lookup init data for time
   ContrInitHeating = table1(InitHeating(:,[1, IxInitMonth+1]), ContrTime);
   ContrInitVentilat= table1(InitVentilat(:,[1, IxInitMonth+1]),ContrTime);
   ContrInitCO2Inj  = table1(InitCO2Inj(:,[1, IxInitMonth+1]) , ContrTime);

% Create some probably very good individuals
   BestChrom = [ContrInitHeating; ContrInitVentilat; ContrInitCO2Inj]';
   
% Create good individuals with some noise inside
   if Nind > size(BestChrom,1),
      % Number of individuals to deal with further
      NindRand = Nind - size(BestChrom,1);
      % Create random index into month array to use
      IxChrom = ceil(rand(NindRand, NCONTR) .* length(IxInitMonth));
      % Collect values from month
      GoodChrom = [ContrInitHeating(:,IxChrom(:,1))', ...
                   ContrInitVentilat(:,IxChrom(:,2))',...
                   ContrInitCO2Inj(:,IxChrom(:,3))'];

      % Initialize a random matrix of reduced size (used noise)
      Chrom = rand(NindRand, Nvar);
      % Set Chrom to random values in 10% of range VLUB
      Chrom = Chrom .* repmat((VLUB(2,:)-VLUB(1,:))/10, [NindRand, 1]);
      % Add noise to good individuals
      Chrom = Chrom + GoodChrom;
      % Collect best and good noisy individuals together
      Chrom = [BestChrom; Chrom];
   else
      % If less individuals to create than in best individuals matrix select
      % only needed individuals
      Chrom = BestChrom(1:Nind,:);
   end
 
% Ensure variable boundaries, compare with lower and upper boundaries
   Chrom = max(repmat(VLUB(1,:),[Nind 1]), Chrom);
   Chrom = min(repmat(VLUB(2,:),[Nind 1]), Chrom);
    
 
 % End of function
