%  Gewchshausklimamodell 'klimod03'
%  Funktion zur Darstellung der Daten: KLIMA, PLANT
%  20.10.1994

function [KLIMA, PLANT] = kliplast(Time, Monat);

   MonatWerte = [2,4,6]; MonatDefault = 2;   % Berechnungsmonat: 2, 4, 6 sind moeglich; 2 ist Standard
   if nargin > 1, if any(Monat==MonatWerte) == 0, Monat = MonatDefault; end, else Monat = MonatDefault; end

   % Zeit-Vektor
   Zeit = [ 0; 1; 2; 3; 4; 5; 6; 7; 8; 9; 10; 11; 12; 13; 14; 15; 16; 17; 18; 19; 20; 21; 22; 23; 24];

   % TEMB, Temperatur der Bodenoberflche, C
   % TEMG, Temperatur der Gewchshaushlle (Innenseite), C
   % TEMA, Auentemperatur, C
   % FA, Auenluftfeuchte, % r.F.
   % CA, Auen-CO2-Konzentration, ppm
   % IGLOB, Globalstrahlung, W/m
   % U, Windgeschwindigkeit, m/s
   % KLIMAold=[20.0  29.44  16.1  73  340  327.8  3.6];
   %  Februar-Daten          TEMB  TEMG  TEMA    FA   CA  IGLOB    U 
   if     Monat == 2, KLIMA=[20.0   0.0  -1.2  89.0  340    0.0  4.9;    %  0 -  1 Uhr
                             20.0   0.0  -1.4  90.0  340    0.0  4.9;    %  1 -  2 Uhr 
                             20.0   0.0  -1.5  90.0  340    0.0  4.9;    %  2 -  3 Uhr
                             20.0   0.0  -1.6  90.0  340    0.0  4.8;    %  3 -  4 Uhr
                             20.0   0.0  -1.8  91.0  340    0.0  4.8;    %  4 -  5 Uhr
                             20.0   0.0  -1.8  91.0  340    0.0  4.7;    %  5 -  6 Uhr
                             20.0   0.0  -1.9  91.0  340    0.0  4.7;    %  6 -  7 Uhr
                             20.0   0.0  -1.8  91.0  340   11.1  4.7;    %  7 -  8 Uhr
                             20.0   0.0  -1.3  90.0  340   58.3  4.7;    %  8 -  9 Uhr
                             20.0   0.0  -0.4  87.0  340  122.2  4.6;    %  9 - 10 Uhr
                             20.0   0.0  -0.6  83.0  340  175.0  4.7;    % 10 - 11 Uhr
                             20.0   0.0   1.4  79.0  340  208.4  4.8;    % 11 - 12 Uhr
                             20.0   0.0   1.9  77.0  340  213.9  4.8;    % 12 - 13 Uhr
                             20.0   0.0   2.3  75.0  340  191.7  4.9;    % 13 - 14 Uhr
                             20.0   0.0   2.2  74.0  340  144.4  4.9;    % 14 - 15 Uhr
                             20.0   0.0   1.9  76.0  340   83.3  4.7;    % 15 - 16 Uhr
                             20.0   0.0   1.2  78.0  340   22.2  4.5;    % 16 - 17 Uhr
                             20.0   0.0   0.6  82.0  340    0.0  4.5;    % 17 - 18 Uhr
                             20.0   0.0   0.2  84.0  340    0.0  4.7;    % 18 - 19 Uhr
                             20.0   0.0  -0.1  85.0  340    0.0  4.8;    % 19 - 20 Uhr
                             20.0   0.0  -0.4  86.0  340    0.0  4.9;    % 20 - 21 Uhr
                             20.0   0.0  -0.6  87.0  340    0.0  4.9;    % 21 - 22 Uhr
                             20.0   0.0  -0.8  88.0  340    0.0  4.9;    % 22 - 23 Uhr
                             20.0   0.0  -1.0  88.0  340    0.0  4.9     % 23 - 24 Uhr
                             20.0   0.0  -1.2  89.0  340    0.0  4.9;    % 24 -  1 Uhr
                            ];

   %  April-Daten            TEMB  TEMG  TEMA    FA   CA  IGLOB    U 
   elseif Monat == 4, KLIMA=[20.0   0.0   5.4  82.0  340    0.0  4.3;    %  0 -  1 Uhr
                             20.0   0.0   5.0  84.0  340    0.0  4.3;    %  1 -  2 Uhr 
                             20.0   0.0   4.7  85.0  340    0.0  4.3;    %  2 -  3 Uhr
                             20.0   0.0   4.4  87.0  340    0.0  4.4;    %  3 -  4 Uhr
                             20.0   0.0   4.1  88.0  340    0.0  4.3;    %  4 -  5 Uhr
                             20.0   0.0   4.2  88.0  340   22.2  4.2;    %  5 -  6 Uhr
                             20.0   0.0   5.0  86.0  340   91.7  4.1;    %  6 -  7 Uhr
                             20.0   0.0   6.5  80.0  340  191.7  4.0;    %  7 -  8 Uhr
                             20.0   0.0   8.0  73.0  340  291.7  4.1;    %  8 -  9 Uhr
                             20.0   0.0   9.3  67.0  340  369.5  4.2;    %  9 - 10 Uhr
                             20.0   0.0  10.3  62.0  340  433.4  4.5;    % 10 - 11 Uhr
                             20.0   0.0  11.1  59.0  340  458.4  4.6;    % 11 - 12 Uhr
                             20.0   0.0  11.7  56.0  340  458.4  4.6;    % 12 - 13 Uhr
                             20.0   0.0  12.1  54.0  340  425.0  4.6;    % 13 - 14 Uhr
                             20.0   0.0  12.2  54.0  340  358.4  4.6;    % 14 - 15 Uhr
                             20.0   0.0  12.0  54.0  340  283.4  4.5;    % 15 - 16 Uhr
                             20.0   0.0  11.5  56.0  340  186.1  4.4;    % 16 - 17 Uhr
                             20.0   0.0  10.7  59.0  340   94.4  4.2;    % 17 - 18 Uhr
                             20.0   0.0   9.4  64.0  340   22.2  4.1;    % 18 - 19 Uhr
                             20.0   0.0   8.3  69.0  340    0.0  4.0;    % 19 - 20 Uhr
                             20.0   0.0   7.6  72.0  340    0.0  4.0;    % 20 - 21 Uhr
                             20.0   0.0   7.0  76.0  340    0.0  4.1;    % 21 - 22 Uhr
                             20.0   0.0   6.4  78.0  340    0.0  4.2;    % 22 - 23 Uhr
                             20.0   0.0   6.0  80.0  340    0.0  4.3     % 23 - 24 Uhr
                             20.0   0.0   5.4  82.0  340    0.0  4.3;    % 24 -  1 Uhr
                            ];
   %  Juni-Daten             TEMB  TEMG  TEMA    FA   CA  IGLOB    U 
   elseif Monat == 6, KLIMA=[20.0   0.0  13.2  84.0  340    0.0  4.0;    %  0 -  1 Uhr
                             20.0   0.0  12.7  86.0  340    0.0  4.1;    %  1 -  2 Uhr 
                             20.0   0.0  12.4  87.0  340    0.0  4.0;    %  2 -  3 Uhr
                             20.0   0.0  12.0  88.0  340    0.0  4.0;    %  3 -  4 Uhr
                             20.0   0.0  12.1  88.0  340   36.1  4.0;    %  4 -  5 Uhr
                             20.0   0.0  12.9  86.0  340  113.9  3.8;    %  5 -  6 Uhr
                             20.0   0.0  14.5  80.0  340  216.7  3.6;    %  6 -  7 Uhr
                             20.0   0.0  16.1  73.0  340  327.8  3.6;    %  7 -  8 Uhr
                             20.0   0.0  17.4  68.0  340  427.8  3.9;    %  8 -  9 Uhr
                             20.0   0.0  18.5  63.0  340  511.2  4.0;    %  9 - 10 Uhr
                             20.0   0.0  19.3  59.0  340  561.2  4.2;    % 10 - 11 Uhr
                             20.0   0.0  20.1  56.0  340  605.6  4.3;    % 11 - 12 Uhr
                             20.0   0.0  20.6  54.0  340  600.0  4.4;    % 12 - 13 Uhr
                             20.0   0.0  21.0  53.0  340  563.9  4.4;    % 13 - 14 Uhr
                             20.0   0.0  21.0  53.0  340  494.5  4.4;    % 14 - 15 Uhr
                             20.0   0.0  20.8  53.0  340  413.9  4.3;    % 15 - 16 Uhr
                             20.0   0.0  20.4  55.0  340  311.1  4.3;    % 16 - 17 Uhr
                             20.0   0.0  19.8  58.0  340  208.4  4.1;    % 17 - 18 Uhr
                             20.0   0.0  18.7  62.0  340  108.3  4.0;    % 18 - 19 Uhr
                             20.0   0.0  17.1  68.0  340   33.3  3.7;    % 19 - 20 Uhr
                             20.0   0.0  15.7  73.0  340    0.0  3.8;    % 20 - 21 Uhr
                             20.0   0.0  14.9  77.0  340    0.0  3.9;    % 21 - 22 Uhr
                             20.0   0.0  14.3  80.0  340    0.0  4.0;    % 22 - 23 Uhr
                             20.0   0.0  13.7  82.0  340    0.0  4.0     % 23 - 24 Uhr
                             20.0   0.0  13.2  84.0  340    0.0  4.0;    % 24 -  1 Uhr
                            ];
   end

   % Berechnung des (Klima)Zeitpunktes durch Umrechnung der Zeit von Sekunden auf Stunden und auf weniger als 24 Uhr
   % Time = rem(floor(Time/3600), 24) + 1;
   % KLIMA = KLIMA(Time,:);
   % Zuweisen der Klimadaten fuer diesen Zeitpunkt
   Time = rem((Time ./ 3600), 24);
   KLIMA = table1([Zeit, KLIMA], Time);
   % [Time, KLIMA(:,[3 4 6 7])]
   
   % Blattflchenindex, A, m/m
   % Transpiration pro Blattflche unter Standardbedingungen, V0, g H2O/(dm.h)
   % CO2-Gaswechsel pro Blattflche unter Standardbedingungen, P0, g CO2/(dm.h)
   %                            A      P0      V0 
   if     Monat == 2, PLANT = [0.5   0.015    1.0];
   elseif Monat == 4, PLANT = [1.5   0.015    1.0];
   elseif Monat == 6, PLANT = [2.5   0.015    1.0];
   end


% end of function
