% short description of function
%
% Diese Funktion berechnet die Transpiration eines Paprika-
% Pflanzenbestandes: V in [g/(m.h)].
%
% Syntax:  V = tranpap3(X, IGLOB, A, V0);
%
% Input parameter:
%    X         - Zustandsgroessen des Gewaechshauses
%    IGLOB     - Globalstrahlung, [W/m]
%    A         - Blattflaechenindex, [m/m]
%    V0        - Transpiration pro Blattflche unter Standard-
%                   bedingungen [g H2O/(dm.h)]
%
% Output parameter:
%    V         - Transpiration eines Paprika-Planzenbestandes
%                   [g H2O/(dm.h)]

%
% See also: sdef, dadr, sdadr

% Author:   Hartmut Pohlheim
% History:  10.03.97    file created


function V = tranpap3(X, IGLOB, A, V0);

   % DDI = X(:,1);
   % TEMI = X(:,2);
   % CI = X(:,3);

   % IGLOB = KLIMA(:,6);
   % A = PLANT(:,1);
   % V0 = PLANT(:,3);
   
   % Convert input data to necessary units
   BQ = 0.71;
   I = BQ * IGLOB;        
   BLFL = A .* 1e2;     % Conversion from m to dm

   % Definition of model specific constants
   A10 = 7.5988; A11 = -0.03089; A2 = 0.06313; A3 = 6.7690; A4 = 0.001040; A5 = 27.7003;

   % Definition of other constants or values
   SDI = sdef(X(:,1), X(:,2));

   % Calculation of the model
   V = (A10 + A11 * BLFL) .* (1 - exp(-A2 * (SDI + A3))) .* (1 - exp(-A4 * (I + A5)));
   V = V .* BLFL;


% End of function
